{% load static %}
<div id="modal"
     _="on closeModal add .closing then wait for animationend then remove me"
     _="on modalFormValid add .closing then wait for animationend then remove me">
    <div class="modal-underlay" _="on click trigger closeModal"></div>
    <div class="modal-content">
        <h1>{{ title }}</h1>
        <div class="modal-body">{{ body }}</div>
        <br>
        <br>
        <button _="on click trigger closeModal">Close</button>
    </div>
</div>
<link href="{% static 'hx_requests/css/modal.css' %}" rel="stylesheet">
